from ocsf.objects.evidences import EvidenceArtifacts
from ocsf.objects.remediation import Remediation
from ocsf.objects.resource_details import ResourceDetails
from ocsf.objects.vulnerability import VulnerabilityDetails

from ocsf.events.findings import Finding


class DetectionFinding(Finding):
    """
    A Detection Finding describes detections or alerts generated by security
    products using correlation engines, detection engines or other methodologies.
    Note: if the product is a security control, the security_control
    profile should be applied and its attacks information should be
    duplicated into the finding_info object.
    """

    class_uid: int = 2004
    class_name: str = 'Detection Finding'

    # Recommended:
    evidences: list[EvidenceArtifacts] | None = None
    resources: list[ResourceDetails] | None = None # Describes details about resources that were the
                                                   # target of the activity that triggered the finding.

    # Optional:
    impact: str | None = None
    impact_id: int | None = None
    impact_score: int | None = None
    remediation: Remediation | None = None
    risk_level: str | None = None
    risk_level_id: int | None = None
    risk_score: int | None = None
    risk_details: str | None = None
    vulnerabilities: list[VulnerabilityDetails] | None = None # Describes vulnerabilities reported in a
                                                       # Detection Finding.
