from datetime import datetime
from pydantic import AnyUrl, BaseModel

from .related_event import RelatedEvent
from .remediation import Remediation


class Finding(BaseModel):
    """
    The Finding object describes metadata related to a security finding generated by
    a security tool or system.
    """

    title: str # A title or a brief phrase summarizing the reported finding.
    uid: str # The unique identifier of the reported finding.


    # Optional:
    created_time: datetime | None = None # The time when the finding was created.
    desc: str | None = None # The description of the reported finding.
    first_seen_time: datetime | None = None # The time when the finding was first observed.
    last_seen_time: datetime | None = None # The time when the finding was most recently observed.
    modified_time: datetime | None = None # The time when the finding was last modified.
    product_uid: str | None = None # The unique identifier of the product that reported the finding.
    related_events: list[RelatedEvent] | None = None
    remediation: Remediation | None = None
    src_url: AnyUrl | None = None # The URL pointing to the source of the finding.
    supporting_data: dict | None = None
    types: list[str] | None = None # One or more types of the reported finding.
