from enum import Enum
from .cve import CVE
from ._entity import Entity

class MalwareClassificationIds(Enum):
    Unknown: int = 0
    Adware: int = 1
    Backdoor: int = 2
    Bot: int = 3
    Bootkit: int = 4
    Ddos: int = 5
    Downloader: int = 6
    Dropper: int = 7
    ExploitKit: int = 8
    Keylogger: int = 9
    Ransomware: int = 10
    Remote_Access_Trojan: int = 11
    Resource_Exploitation: int = 13
    Rogue_Security_Software: int = 14
    Rootkit: int = 15
    Screen_Capture: int = 16
    Spyware: int = 17
    Trojan: int = 18
    Virus: int = 19
    Webshell: int = 20
    Wiper: int = 21
    Worm: int = 22
    Other: int = 99

class Malware(Entity):
    """
    The Malware object describes the classification of known malicious software,
    which is intentionally designed to cause damage to a computer, server, client,
    or computer network.
    """

    classification_ids: MalwareClassificationIds

    # Recommended:
    path: str | None = None # The filesystem path of the malware that was observed.
    provider: str | None = None # The provider of the malware information.

    # Optional:
    classifications: list[str] | None = None
    cves: list[CVE] | None = None
    name: str | None = None # The malware name, as reported by the detection engine.
    uid: str | None = None # The malware unique identifier, as reported by the detection engine. For
                           # example a virus id or an IPS signature id.
