from pydantic import BaseModel

from .kb_article import KBArticle
from .affected_code import AffectedCode
from datetime import datetime
from .cve import CVE
from .affected_package import AffectedSoftwarePackage
from .remediation import Remediation
from .cwe import CWE
from .package import SoftwarePackage

class VulnerabilityDetails(BaseModel):
    """
    The vulnerability is an unintended characteristic of a computing component or
    system configuration that multiplies the risk of an adverse event or a loss
    occurring either due to accidental exposure, deliberate attack, or conflict with
    new system components.
    """

    # Recommended:
    cve: CVE | None = None
    cwe: CWE | None = None
    references: list[str] | None = None # A list of reference URLs with additional information about
                                        # the vulnerability.

    # Optional:
    affected_code: list[AffectedCode] | None = None
    affected_packages: list[AffectedSoftwarePackage] | None = None
    desc: str | None = None # The description of the vulnerability.
    first_seen_time: datetime | None = None # The time when the vulnerability was first observed.
    fix_available: bool | None = None
    kb_articles: list[str] | None = None
    kb_article_list: list[KBArticle] | None = None
    is_exploit_available: bool | None = None
    is_fix_available: bool | None = None
    last_seen_time: datetime | None = None # The time when the vulnerability was most recently
                                           # observed.
    packages: list[SoftwarePackage] | None = None
    related_vulnerabilities: list[str] | None = None
    remediation: Remediation | None = None # The remediation recommendations on how to mitigate the
                                           # identified vulnerability.
    severity: str | None = None # The vendor assigned severity of the vulnerability.
    title: str | None = None # A title or a brief phrase summarizing the discovered vulnerability.
    vendor_name: str | None = None # The name of the vendor that identified the vulnerability.
